export interface HdKeypair {
    key: Buffer;
    chainCode: Buffer;
}
/**
 * Heirarchical determinisitic key derivation for the ed25519 elliptic curve,
 * as defined in SLIP-0010.
 *
 * https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0005.md
 * https://github.com/satoshilabs/slips/blob/master/slip-0010.md
 *
 * @deprecated
 */
export declare class Ed25519KeyDeriver {
    /**
     * This key derivation code was copied and adapted from:
     * https://github.com/chatch/stellar-hd-wallet/blob/612c12325ca9047dce460016fb7d148f55f575ca/src/hd-key.js
     *
     * There have been some slight modifications to improve typescript support.
     *
     * The original ed25519-hd-key module is licensed under "GPL-3".
     */
    private static readonly ED25519_CURVE;
    private static readonly HARDENED_OFFSET;
    private static readonly PATH_REGEX;
    /**
     * Derive a SLIP-0010 key given a path and master key seed.
     *
     * @param path derivation path
     * @param seed key seed
     */
    static derivePath(path: string, seed: string): HdKeypair;
    /**
     * Generate a SLIP-0010 master key from the entropy seed
     *
     * @param seed master key seed used to recreate master key
     */
    private static getMasterKeyFromSeed;
    /**
     * Calculate a child private key given the parent key, the chain code, and the child index.
     *
     * @param key parent key
     * @param chainCode chain code for parent key
     * @param index index of child to derive
     */
    private static CKDPriv;
    private static replaceDerive;
    private static isValidPath;
}
//# sourceMappingURL=ed25519KeyDeriver.d.ts.map