import { EnvironmentName } from './environments';
export type KrsProvider = {
    feeType: 'flatUsd';
    feeAmount: number;
    supportedCoins: string[];
    feeAddresses?: Record<string, string>;
};
export declare const krsProviders: Record<string, KrsProvider>;
export declare const defaults: {
    maxFee: number;
    maxFeeRate: number;
    minFeeRate: number;
    fallbackFeeRate: number;
    minOutputSize: number;
    minInstantFeeRate: number;
    bitgoEthAddress: string;
};
/**
 * Get the default (hardcoded) constants for a particular network.
 *
 * Note that this may not be the complete set of constants, and additional constants may get fetched
 * from BitGo during the lifespan of a BitGo object.
 * @param env
 */
export declare const defaultConstants: (env: EnvironmentName) => {
    maxFee: number;
    maxFeeRate: number;
    minFeeRate: number;
    fallbackFeeRate: number;
    minOutputSize: number;
    minInstantFeeRate: number;
    bitgoEthAddress: string;
} & ({
    eth: {
        tokens: import("@bitgo/statics").Erc20TokenConfig[];
    };
    xlm: {
        tokens: import("@bitgo/statics").StellarTokenConfig[];
    };
    algo: {
        tokens: import("@bitgo/statics").AlgoTokenConfig[];
    };
    ofc: {
        tokens: import("@bitgo/statics").OfcTokenConfig[];
    };
    celo: {
        tokens: import("@bitgo/statics").CeloTokenConfig[];
    };
    eos: {
        tokens: import("@bitgo/statics").EosTokenConfig[];
    };
    avaxc: {
        tokens: import("@bitgo/statics").AvaxcTokenConfig[];
    };
    polygon: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    soneium: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    bsc: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    arbeth: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    opeth: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    coredao: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    sol: {
        tokens: import("@bitgo/statics").SolTokenConfig[];
    };
    hbar: {
        tokens: import("@bitgo/statics").HbarTokenConfig[];
    };
    ada: {
        tokens: import("@bitgo/statics").AdaTokenConfig[];
    };
    trx: {
        tokens: import("@bitgo/statics").TrxTokenConfig[];
    };
    xrp: {
        tokens: import("@bitgo/statics").XrpTokenConfig[];
    };
    zketh: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    sui: {
        tokens: import("@bitgo/statics").SuiTokenConfig[];
    };
    bera: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    apt: {
        tokens: import("@bitgo/statics").AptTokenConfig[];
        nftCollections: import("@bitgo/statics").AptNFTCollectionConfig[];
    };
    stx: {
        tokens: import("@bitgo/statics").Sip10TokenConfig[];
    };
    near: {
        tokens: import("@bitgo/statics").Nep141TokenConfig[];
    };
} | {
    eth: {
        tokens: import("@bitgo/statics").Erc20TokenConfig[];
    };
    xlm: {
        tokens: import("@bitgo/statics").StellarTokenConfig[];
    };
    algo: {
        tokens: import("@bitgo/statics").AlgoTokenConfig[];
    };
    ofc: {
        tokens: import("@bitgo/statics").OfcTokenConfig[];
    };
    celo: {
        tokens: import("@bitgo/statics").CeloTokenConfig[];
    };
    bsc: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    eos: {
        tokens: import("@bitgo/statics").EosTokenConfig[];
    };
    avaxc: {
        tokens: import("@bitgo/statics").AvaxcTokenConfig[];
    };
    polygon: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    soneium: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    arbeth: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    opeth: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    sol: {
        tokens: import("@bitgo/statics").SolTokenConfig[];
    };
    hbar: {
        tokens: import("@bitgo/statics").HbarTokenConfig[];
    };
    ada: {
        tokens: import("@bitgo/statics").AdaTokenConfig[];
    };
    trx: {
        tokens: import("@bitgo/statics").TrxTokenConfig[];
    };
    xrp: {
        tokens: import("@bitgo/statics").XrpTokenConfig[];
    };
    zketh: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    sui: {
        tokens: import("@bitgo/statics").SuiTokenConfig[];
    };
    bera: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    coredao: {
        tokens: import("@bitgo/statics").EthLikeTokenConfig[];
    };
    apt: {
        tokens: import("@bitgo/statics").AptTokenConfig[];
        nftCollections: import("@bitgo/statics").AptNFTCollectionConfig[];
    };
    stx: {
        tokens: import("@bitgo/statics").Sip10TokenConfig[];
    };
    near: {
        tokens: import("@bitgo/statics").Nep141TokenConfig[];
    };
});
export type Config = {
    krsProviders: Record<string, KrsProvider>;
};
//# sourceMappingURL=config.d.ts.map