/**
 * @prettier
 */
import { BitGoBase } from '../bitgoBase';
import { ITradingAccount, SignPayloadParameters } from '../trading';
import { IWallet } from '../wallet';
import { TradingNetwork } from './network';
export declare class TradingAccount implements ITradingAccount {
    private readonly bitgo;
    private readonly enterpriseId;
    wallet: IWallet;
    constructor(enterpriseId: string, wallet: IWallet, bitgo: BitGoBase);
    get id(): string;
    /**
     * Signs an arbitrary payload with the user key on this trading account
     * @param params
     * @param params.payload arbitrary payload object (string | Record<string, unknown>)
     * @param params.walletPassphrase passphrase on this trading account, used to unlock the account user key
     * @returns hex-encoded signature of the payload
     */
    signPayload(params: SignPayloadParameters): Promise<string>;
    /**
     * Get Trade Network
     * To enable Off Exchange Allocation & Settlement, contact support@bitgo.com.
     * BitGo provides a UI experience for clients at: https://app.bitgo.com/web/enterprises/<enterpriseId>/allocate
     */
    toNetwork(): TradingNetwork;
}
//# sourceMappingURL=tradingAccount.d.ts.map